@@ -468,7 +468,7 @@ class GithubCustomResource(
                 scope: constructs.Construct,
                 id: builtins.str,
                 *,
-                auth_options: "IAuthOptions",
+                auth_options: IAuthOptions,
                 on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
                 on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
                 on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
@@ -571,7 +571,7 @@ class GithubCustomResourceProps:
         if __debug__:
             def stub(
                 *,
-                auth_options: "IAuthOptions",
+                auth_options: IAuthOptions,
                 on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
                 on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
                 on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
